@@ -7,7 +7,7 @@ BEGIN {
 	unshift @INC, '../lib';
 }
 
-use Weed 'WeedTest : X3DBaseNode {
+use Weed 'Weed : X3DNode {
   SFNode   [in,out] metadata    NULL    [X3DMetadataObject]
   MFString []       family      "SERIF"
   SFBool   []       horizontal  FALSE
@@ -18,8 +18,8 @@ use Weed 'WeedTest : X3DBaseNode {
   SFBool   []       leftToRight TRUE
   SFFloat  []       size        1.0     (0,\u221e)
   SFFloat  []       spacing     1.0     [0,\u221e)
-  SFString [in,out]    style       "BOLD" ["PLAIN"|"BOLD"|"ITALIC"|"BOLDITALIC"|""]
-  SFBool   [in]     topToBottom
+  SFString [out]    style       "BOLD" ["PLAIN"|"BOLD"|"ITALIC"|"BOLDITALIC"|""]
+  SFBool   [in]     topToBottom TRUE
 }
 ';
 
